'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var require$$0 = require('react-dom');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var require$$0__default = /*#__PURE__*/_interopDefaultLegacy(require$$0);

const Applet = ({ name, host, context }) => {
    const APPLICATION_ID = `applet-${name}`;
    const SCRIPT_ID = `applet-script-${name}`;
    const MANIFEST = `${host}/asset-manifest.json`;
    const MOUNT = `mount${name}`;
    const UNMOUNT = `unmount${name}`;
    const KEY = `applet-${name}-${Date.now()}`;
    React.useEffect(() => {
        const renderApplet = () => {
            window[MOUNT](APPLICATION_ID, context);
        };
        if (document.getElementById(SCRIPT_ID)) {
            renderApplet();
            return;
        }
        fetch(MANIFEST)
            .then((res) => res.json())
            .then((manifest) => {
            const script = document.createElement("script");
            script.id = SCRIPT_ID;
            script.crossOrigin = "";
            script.src = `${host}${manifest.files["main.js"]}`;
            script.onload = renderApplet;
            document.body.appendChild(script);
        });
        return () => {
            // Ignoring this line because it's not possible to test
            // due to a bug in testing-library where effect cleanups
            // are not called when unmounting.
            // istanbul ignore next
            window[UNMOUNT] && window[UNMOUNT]();
        };
    });
    return React__default["default"].createElement("main", { id: APPLICATION_ID, key: KEY });
};

function configureApplets(config) {
    return Object.entries(config).reduce((apps, [key, app]) => {
        const { host, context } = app;
        return Object.assign(Object.assign({}, apps), { [key]: () => React__default["default"].createElement(Applet, { host: host, name: key, context: context }) });
    }, {});
}

var client = {};

var m = require$$0__default["default"];
if (process.env.NODE_ENV === 'production') {
  client.createRoot = m.createRoot;
  client.hydrateRoot = m.hydrateRoot;
} else {
  var i = m.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED;
  client.createRoot = function(c, o) {
    i.usingClientEntryPoint = true;
    try {
      return m.createRoot(c, o);
    } finally {
      i.usingClientEntryPoint = false;
    }
  };
  client.hydrateRoot = function(c, h, o) {
    i.usingClientEntryPoint = true;
    try {
      return m.hydrateRoot(c, h, o);
    } finally {
      i.usingClientEntryPoint = false;
    }
  };
}

const AppletContext = React.createContext({});
const AppletContextProvider = ({ context, children, }) => (React__default["default"].createElement(AppletContext.Provider, { value: context }, children));
const useAppletContext = () => React.useContext(AppletContext);

const initializeApplet = (name, Applet, developmentContext = {}) => {
    let root = null;
    window[`mount${name}`] = (containerId, context) => {
        if (!root) {
            root = client.createRoot(document.getElementById(containerId));
        }
        root.render(React__default["default"].createElement(AppletContextProvider, { context: context },
            React__default["default"].createElement(Applet, null)));
        window[`unmount${name}`] = () => {
            root.unmount();
        };
    };
    if (process.env.NODE_ENV === "development" &&
        process.env.REACT_APP_ISOLATED_APPLET) {
        window[`mount${name}`](process.env.REACT_APP_ISOLATED_CONTAINER || "root", developmentContext);
    }
};

exports.configureApplets = configureApplets;
exports.initializeApplet = initializeApplet;
exports.useAppletContext = useAppletContext;
